@@ -4,7 +4,7 @@ use Carp;
 use IO::Handle; # for 'autoflush'
 use JSON;
 
-our $VERSION= '0.01';
+our $VERSION= '0.03';
 
 # ABSTRACT: Conveniently write progress messages to logger or file handle
 
@@ -95,7 +95,7 @@ sub progress {
 sub data {
 	my ($self, $data)= @_;
 	ref $data eq 'HASH' or croak "data must be a hashref";
-	$self->_writer->(JSON->new->encode($data));
+	$self->_writer->(JSON->new->ascii->encode($data));
 }
 
 
@@ -136,26 +136,26 @@ Log::Progress - Conveniently write progress messages to logger or file handle
 
 =head1 VERSION
 
-version 0.01
+version 0.03
 
 =head1 SYNOPSIS
 
   my $p= Log::Progress->new(to => \*STDERR); # The default
   $p->squelch(.1); # only emit messages every 10%
   my $max= 1000;
-  for (my $i= 0; $i < $max; $i++) {
+  for (my $i= 1; $i <= $max; $i++) {
     # do the thing
     ...;
-    $p->progress(($i+1)/$max);
-    # -or-
-    $p->progress_ratio($i+1, $max);
+    $p->progress($i, $max);
   }
 
 =head1 DESCRIPTION
 
-This module assists with writing the Log::Progress protocol, which can then
-be parsed with the Log::Progress::Parser.  It can write to file handles, log
-objects (like Log::Any), a coderef, or any object with a "print" method.
+This module assists with writing
+L<progress messages|http://github.com/nrdvana/Log-Progress/blob/master/README.md>
+to your log file, which can then be parsed with L<Log::Progress::Parser>.
+It can write to file handles, log objects (like L<Log::Any>),
+or custom coderefs.
 
 Note that this module enables autoflush if you give it a file handle.
 
@@ -163,9 +163,7 @@ Note that this module enables autoflush if you give it a file handle.
 
 =head2 to
 
-The destination for progress messages.  \*STDERR is the default.
-You can pass any file handle or handle-like object with a C<print> method,
-Logger object with C<info> method, or a custom coderef.
+The destination for progress messages.  It can be one of:
 
 =over
 
@@ -185,7 +183,7 @@ newline.
 
 The progress messages are passed as the only argument, without a terminating
 newline.  The return value becomes the return value of the call to L</progress>
-and should probably be a boolean to match behavior of C<<$handle->print>>.
+and should probably be a boolean to match behavior of C<IO::Handle::print>.
 
   sub { my ($progress_message)= @_; ... }
 
@@ -195,28 +193,28 @@ and should probably be a boolean to match behavior of C<<$handle->print>>.
 
 The progress number is written as text, with L</precision> digits after the
 decimal point.  The default precision is 2.  This default corresponds with a
-default L</squelch> of 0.01, so that calls to ->progress with less than 1%
-change from the previous call are suppressed.
+default L</squelch> of 0.01, so that calls to C<< ->progress >> with less
+than 1% change from the previous call are suppressed.
 
-If you set precision but not squelch, the second will use a default to match
-the one you specified.  For example, setting a precision of 5 results in a
-default squelch of .00001, or a default squelch of 350 results in a precision
-of 3.
+If you set only one of C<precision> or C<squelch>, the other will default to
+something appropriate.  For example, setting C<precision> to C<5> results in
+a C<squelch> of C<.00001>.  Likewise a squelch of C<1/60> gives a precision
+of C<2>.
 
-Once set, precision will not receive a default value from changes to squelch.
+Once set, C<precision> will not receive a default value from changes to C<squelch>.
 (but you can un-define it to restore that behavior)
 
 =head2 squelch
 
 You can prevent spamming your log file with tiny progress updates using
-"squelch", which limits progress messages to one per some fraction of overall
-progress.  For example, the default squelch of .01 will only emit at most 101
-progress messages.  (unless you start reporting negative progress)
+C<squelch>, which limits progress messages to one per some fraction of overall
+progress.  For example, the default C<squelch> of C<.01> will only emit at most
+C<101> progress messages.  (assuming your progress is non-decreasing)
 
-If you set squelch but not precision, the second will use a sensible default.
+If you set C<squelch> but not C<precision>, the second will use a sensible default.
 See example in L</precision>
 
-Once set, squelch will not receive a default value from changing precision.
+Once set, C<squelch> will not receive a default value from changing C<precision>.
 (but you can un-define it to restore that behavior)
 
 =head2 step_id
@@ -247,7 +245,7 @@ a whole number.
 =head2 data
 
 If you want to write any progress-associated data, use this method.
-The data must be a hashref.
+The data must be a hashref.  It gets encoded as pure-ascii JSON.
 
 =head2 substep
 
